#
# spec file for package python-concurrentloghandler
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname concurrent-log-handler
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-concurrentloghandler
Version:        0.9.19
Release:        2.15
Summary:        Concurrent logging handler
License:        Apache-2.0
Group:          Development/Libraries/Python
URL:            https://github.com/Preston-Landers/concurrent-log-handler
Source:         https://github.com/Preston-Landers/%{modname}/archive/%{version}.tar.gz#/%{modname}-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM test_returncode.patch bsc#[0-9]+ mcepl@suse.com
# test script should return errorlevel
# Patch0:         test_returncode.patch
BuildRequires:  %{python_module portalocker}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  sed
BuildArch:      noarch
%python_subpackages

%description
This module provides an additional log handler for Python's
standard logging package (PEP 282). This handler will write log
events to log file which is rotated when the log file reaches
a certain size. Multiple processes can safely write to the same
log file concurrently.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
# Remove files installed in wrong places
rm -rf %{buildroot}%{_usr}/{docs,tests}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
rm -rf test_output
$python stresstest.py
}

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/*

%changelog
* Tue Jul 27 2021 Matej Cepl <mcepl@suse.com>
- Stupid me: it should be rm -rf test_output, not just rm -rf
  test (gh#Preston-Landers/concurrent-log-handler#38).
* Wed Mar 17 2021 Matej Cepl <mcepl@suse.com>
  Update to 0.9.19:
    0.9.19: Fix Python 2 compatibility (again), thanks @buddly27
    Fix accidental detection of 'darwin' (Mac OS) as
    Windows in setup.py
    0.9.18: Remove ez_setup from the setup.py
    0.9.17: Contains the following fixes:
  - Catch exceptions when unlocking the lock.
  - Clarify documentation, esp. with use of multiprocessing
  - In Python 2, don't request/allow portalocker 2.0 which
    won't work. (Require portalocker<=1.7.1)
    0.9.16: Fix publishing issue with incorrect code included in
    the wheel Affects Python 2 mainly - see Issue #21
    0.9.15: Fix bug from last version on Python 2. (Issue #21)
    Thanks @condontrevor Also, on Python 2 and 3, apply
    unicode_error_policy (default: ignore) to convert
    a log message to the output stream's encoding. I.e.,
    by default it will filter out (remove) any characters
    in a log message which cannot be converted to the
    output logfile's encoding.
    0.9.14: Fix writing LF line endings on Windows when encoding
    is specified. Added newline and terminator kwargs to
    allow customizing line ending behavior. Thanks to
    @vashek
    0.9.13: Fixes Crashes with ValueError: I/O operation on
    closed file (issue #16) Also should fix issue #13
    with crashes related to Windows file locking. Big
    thanks to @terencehonles, @nsmcan, @wkoot, @dismine
    for doing the hard parts
    0.9.12: Add umask option (thanks to @blakehilliard) This adds
    the ability to control the permission flags when
    creating log files.
    0.9.11: Fix issues with gzip compression option (use
    buffering)
    0.9.10: Fix inadvertent lock sharing when forking Thanks to
    @eriktews for this fix
    0.9.9: Fix Python 2 compatibility broken in last release
    0.9.8: Bug fixes and permission features
  - Fix for issue #4 - AttributeError: 'NoneType' object has
    no attribute 'write' This error could be caused if
    a rollover occurred inside a logging statement that was
    generated from within another logging statement's
    format() call.
  - Fix for PyWin32 dependency specification (explicitly
    require PyWin32)
  - Ability to specify owner and permissions (mode) of
    rollover files [Unix only]
    0.9.7/0.9.6: Fix platform specifier for PyPi
    0.9.5: Add use_gzip option to compress rotated logs. Add an
    optional threaded logging queue handler based on the
    standard library's logging.QueueHandler.
    0.9.4: Fix setup.py to not include tests in distribution.
    0.9.3: Refactoring release
  - For publishing fork on pypi as concurrent-log-handler
    under new package name.
  - NOTE: PyWin32 is required on Windows but is not an
    explicit dependency because the PyWin32 package is not
    currently installable through pip.
  - Fix lock behavior / race condition
    0.9.2: Initial release of fork by Preston Landers based on
    a fork of Lowell Alleman's ConcurrentLogHandler 0.9.1
  - Fixes deadlocking issue with recent versions of Python
  - Puts .__ prefix in front of lock file name
  - Use secrets or SystemRandom if available.
  - Add/fix Windows support
- Remove ConcurrentLogHandler-0.9.1-testpath.patch, which is
  unnecessary
* Thu May 17 2018 mcepl@suse.com
- Fix tests
* Thu May 17 2018 mcepl@suse.com
- Run spec-cleaner on the SPEC file.
- Fix SPEC file to work according to the latest standards
- Failed to make tests working.
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Wed Jul 20 2016 antoine.belvire@laposte.net
- Fix build (boo#985412):
  * Use --record-rpm instead of --record for listing files
    installed with setup.py
  * Fix ConcurrentLogHandler-0.9.1-testpath.patch: py files were
    not installed.
* Thu Sep 26 2013 p.drouand@gmail.com
- Update to version 0.9.1
  + Bug fixes - LP Bug 1199332 and LP Bug 1199333
  +  More gracefully handle out of disk space scenarios. Prevent release()
    from throwing an exception
  +  Handle logging.shutdown() in Python 2.7+. Close the lock file stream
    via close()
- Changes between 0.9.0 and 0.8.6
  + Now requires Python 2.6+
  + Revamp file opening/closing and file-locking internals
  + Add the 'delay' parameter (delayed log file opening) to better match
    the core logging functionality in more recent version of Python.
  + For anyone still using Python 2.3-2.5, please use the latest 0.8.x release
- Changes between 0.8.6 and 0.8.5
  + Fix a small packaging bug from the 0.8.5 release.
  + Updated stresstest.py to always use the correct python version when
    launching sub-processes instead of the system's default "python"
- Changes between 0.8.5 and 0.8.4
  + Bugs resolved Red Hat Bug #858912 and Python Bug #15960
  + Updated ez_setup.py to 0.7.7
  + Updated portalocker to 0.3
  + Initial Python 3 support
  + Fixed minor spelling mistakes
- Rebase specfile
- Rebase ConcurrentLogHandler-0.8.4-testpath.patch to work with upstream changes
* Tue Jun 22 2010 hvogel@novell.com
- Initial Package, Version 0.8.4
